@@ -9,6 +9,7 @@ from cupyx.scipy.sparse.base import spmatrix
 
 from cupy_backends.cuda.libs import cusparse
 from cupy.cuda import device
+from cupy.cuda import runtime
 
 import numpy
 
@@ -25,7 +26,7 @@ _bool_scalar_types = (bool, numpy.bool_)
 _compress_getitem_kern = _core.ElementwiseKernel(
     'T d, S ind, int32 minor', 'raw T answer',
     'if (ind == minor) atomicAdd(&answer[0], d);',
-    'compress_getitem')
+    'cupyx_scipy_sparse_compress_getitem')
 
 
 _compress_getitem_complex_kern = _core.ElementwiseKernel(
@@ -37,7 +38,7 @@ _compress_getitem_complex_kern = _core.ElementwiseKernel(
     atomicAdd(&answer_imag[0], imag);
     }
     ''',
-    'compress_getitem_complex')
+    'cupyx_scipy_sparse_compress_getitem_complex')
 
 
 def _get_csr_submatrix_major_axis(Ax, Aj, Ap, start, stop):
@@ -107,7 +108,7 @@ _csr_row_index_ker = _core.ElementwiseKernel(
 
     Bj = Aj[starting_input_offset + output_offset];
     Bx = Ax[starting_input_offset + output_offset];
-''', 'csr_row_index_ker')
+''', 'cupyx_scipy_sparse_csr_row_index_ker')
 
 
 def _csr_row_index(Ax, Aj, Ap, rows):
@@ -141,6 +142,9 @@ def _csr_indptr_to_coo_rows(nnz, Bp):
     # Calling backend cusparse API directly to avoid
     # constructing a whole COO object.
     handle = device.get_cusparse_handle()
+    if runtime.is_hip and nnz == 0:
+        raise ValueError('hipSPARSE currently cannot handle '
+                         'sparse matrices with null ptrs')
     cusparse.xcsr2coo(
         handle, Bp.data.ptr, nnz, Bp.size-1, out_rows.data.ptr,
         cusparse.CUSPARSE_INDEX_BASE_ZERO)
@@ -258,7 +262,7 @@ _insert_many_populate_arrays = _core.ElementwiseKernel(
 
             output_n++;
         }
-    ''', 'csr_copy_existing_indices_kern', no_return=True)
+    ''', 'cupyx_scipy_sparse_csr_copy_existing_indices_kern', no_return=True)
 
 
 # Create a filter mask based on the lowest value of order
@@ -281,7 +285,9 @@ _unique_mask_kern = _core.ElementwiseKernel(
         else
             mask[i+1] = false;
     }
-    """, no_return=True
+    """,
+    'cupyx_scipy_sparse_unique_mask_kern',
+    no_return=True
 )
 
 
@@ -328,7 +334,7 @@ _csr_sample_values_kern = _core.ElementwiseKernel(
         }
     }
     Bx[i] = val_found ? x : not_found_val;
-''', 'csr_sample_values_kern')
+''', 'cupyx_scipy_sparse_csr_sample_values_kern')
 
 
 class IndexMixin(object):
